==> Spec-Recorder%20Ver.1.30.zip: Spec-Recorder Ver.1.30/make_csv.py <==
# -*- coding: utf-8 -*-
from PIL import Image
#import datetime
import sys
import libhro
import time
import csv
import libhro
import ConfigParser
#global img

argvs = sys.argv
#if len(argvs) != 2:
#	print "Error this program require two argment"
#	exit()
	
conf = ConfigParser.SafeConfigParser()
conf.read("./sr.conf")
echo_threshold = int(conf.get("analyze", "echo_threshold"))
unite_echo_threshold = int(conf.get("analyze", "unite_echo_threshold"))
compared_with_pixels = conf.get("analyze", "compared_with_pixels")
get_pixel = conf.get("analyze", "get_pixel")

filetime = ""
filename = ""
filetime = argvs[2]
#filetime = "1306140505"
#argvs = ["-a", filetime]
#filename = filetime + ".png"
#pos = (2500,35)
#open_image(filename)
#img = Image.open(filename)
strength_list = []
analyze_return = ()
#8,16,25,33,41,49,58,66,74,82,90,99,107,115,123,132,140,148,156,165,173,181,189,197,206,214,222,230,239,247
"""
def make_csv_a(filetime, strength_list, echo_threshold, unite_echo_threshold):
	filetime = argvs[2]
	libhro.read_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list, echo_threshold, unite_echo_threshold)
	writetxt = open("./echo/" + filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 

def make_csv_c(filetime, strength_list, echo_threshold, unite_echo_threshold):
	filename = argvs[2] + ".png"
	filetime = argvs[2]
	img = Image.open("./monoPNG/" + filename[:])
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	
def make_csv_ac(filetime, strength_list, echo_threshold, unite_echo_threshold):
	filetime = argvs[2]
	filename = argvs[2] + ".png"
	img = Image.open("./monoPNG/" + filename[:])
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list, echo_threshold, unite_echo_threshold)
	writetxt = open("./echo/" + filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 
"""

if argvs[1] == "-a":#エコーカウントのみ
	libhro.make_csv("a", filetime, echo_threshold, unite_echo_threshold, compared_with_pixels, get_pixel)
"""
	filetime = argvs[2]
	libhro.read_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list, echo_threshold, unite_echo_threshold)
	writetxt = open("./echo/" + filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 
"""	
if argvs[1] == "-c":#CSVファイル作成のみ
	libhro.make_csv("c", filetime, echo_threshold, unite_echo_threshold, compared_with_pixels,get_pixel)
	"""
	filename = argvs[2] + ".png"
	filetime = argvs[2]
	img = Image.open("./monoPNG/" + filename[:])
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	"""
	
if argvs[1] == "-ac":#両方
	libhro.make_csv("ac", filetime, echo_threshold, unite_echo_threshold, compared_with_pixels, get_pixel)
	"""
	filetime = argvs[2]
	filename = argvs[2] + ".png"
	img = Image.open("./monoPNG/" + filename[:])
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list, echo_threshold, unite_echo_threshold)
	writetxt = open("./echo/" + filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 
	"""
	
#strength_list = make_list()
#read_csv(strength_list, filetime)
#print strength_list
#print len(strength_list)
#write_csv(strength_list, filetime)
#analyze_return = analyze(strength_list)
exit()

==> Spec-Recorder%20Ver.1.40.zip: Spec-Recorder Ver.1.40/make_csv.py <==
# -*- coding: utf-8 -*-
from PIL import Image
#import datetime
import sys
import libhro
import time
import csv
import libhro
import ConfigParser
#global img

argvs = sys.argv
#if len(argvs) != 2:
#	print "Error this program require two argment"
#	exit()
	
conf = ConfigParser.SafeConfigParser()
conf.read("./sr.conf")
echo_threshold = int(conf.get("analyze", "echo_threshold"))
unite_echo_threshold = int(conf.get("analyze", "unite_echo_threshold"))
compared_with_pixels = conf.get("analyze", "compared_with_pixels")
get_pixel = conf.get("analyze", "get_pixel")

filetime = ""
filename = ""
filetime = argvs[2]
header = argvs[3]
#filetime = "1306140505"
#argvs = ["-a", filetime]
#filename = filetime + ".png"
#pos = (2500,35)
#open_image(filename)
#img = Image.open(filename)
strength_list = []
analyze_return = ()
#8,16,25,33,41,49,58,66,74,82,90,99,107,115,123,132,140,148,156,165,173,181,189,197,206,214,222,230,239,247
"""
def make_csv_a(filetime, strength_list, echo_threshold, unite_echo_threshold):
	filetime = argvs[2]
	libhro.read_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list, echo_threshold, unite_echo_threshold)
	writetxt = open("./echo/" + filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 

def make_csv_c(filetime, strength_list, echo_threshold, unite_echo_threshold):
	filename = argvs[2] + ".png"
	filetime = argvs[2]
	img = Image.open("./monoPNG/" + filename[:])
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	
def make_csv_ac(filetime, strength_list, echo_threshold, unite_echo_threshold):
	filetime = argvs[2]
	filename = argvs[2] + ".png"
	img = Image.open("./monoPNG/" + filename[:])
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list, echo_threshold, unite_echo_threshold)
	writetxt = open("./echo/" + filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 
"""

if argvs[1] == "-a":#エコーカウントのみ
	libhro.make_csv("a", filetime, echo_threshold, unite_echo_threshold, compared_with_pixels, get_pixel, header)
"""
	filetime = argvs[2]
	libhro.read_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list, echo_threshold, unite_echo_threshold)
	writetxt = open("./echo/" + filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 
"""	
if argvs[1] == "-c":#CSVファイル作成のみ
	libhro.make_csv("c", filetime, echo_threshold, unite_echo_threshold, compared_with_pixels,get_pixel, header)
	"""
	filename = argvs[2] + ".png"
	filetime = argvs[2]
	img = Image.open("./monoPNG/" + filename[:])
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	"""
	
if argvs[1] == "-ac":#両方
	libhro.make_csv("ac", filetime, echo_threshold, unite_echo_threshold, compared_with_pixels, get_pixel, header)
	"""
	filetime = argvs[2]
	filename = argvs[2] + ".png"
	img = Image.open("./monoPNG/" + filename[:])
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list, echo_threshold, unite_echo_threshold)
	writetxt = open("./echo/" + filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 
	"""
	
#strength_list = make_list()
#read_csv(strength_list, filetime)
#print strength_list
#print len(strength_list)
#write_csv(strength_list, filetime)
#analyze_return = analyze(strength_list)
exit()
